.. Lollipop documentation master file

*********************************************
lollipop: object serialization and validation
*********************************************

Guide
=====

.. toctree::
    :maxdepth: 2

    install
    quickstart
    custom_types

API Reference
=============

.. toctree::
    :maxdepth: 3

    api_reference

